@@ -3,10 +3,7 @@ use strict;
 use warnings;
 
 package Geo::Openstreetmap::Parser;
-{
-  $Geo::Openstreetmap::Parser::VERSION = '0.02';
-}
-
+$Geo::Openstreetmap::Parser::VERSION = '0.03';
 # ABSTRACT: Openstreetmap XML dump parser
 
 use autodie;
@@ -51,38 +48,30 @@ sub _init_parser
                     my ($expat, $el) = @_;
                     my $obj = pop @path;
 
-                    for ( $el ) {
-                        when ('tag')    { $path[-1]->{$el}->{$obj->{attr}->{k}} = $obj->{attr}->{v} }
-                        when ('nd')     { push @{$path[-1]->{$el}}, $obj->{attr}->{ref} }
-                        when ('member') { push @{$path[-1]->{$el}}, $obj->{attr} }
-                        when ($self->{callback})    { $self->{callback}->{$el}->($obj) }
-                    }
+                    if ($el eq 'tag')    { $path[-1]->{$el}->{$obj->{attr}->{k}} = $obj->{attr}->{v} }
+                    if ($el eq 'nd')     { push @{$path[-1]->{$el}}, $obj->{attr}->{ref} }
+                    if ($el eq 'member') { push @{$path[-1]->{$el}}, $obj->{attr} }
+                    if (my $cb = $self->{callback}->{$el})    { $cb->($obj) }
                 },
         });
     return;
 }
 
-
-sub _process_object
-{
-    my ($self, $el, $obj) = @_;
-
-    $self->{$el}->($obj)  if $self->{$el};
-    return;
-}
-
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Geo::Openstreetmap::Parser - Openstreetmap XML dump parser
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 METHODS
 
@@ -120,10 +109,9 @@ liosha <liosha@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by liosha.
+This software is copyright (c) 2015 by liosha.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
